function val = GG_min(M)

%**************************************************************************
%*                                                                        *
%* GG_MIN returns a bound for smallest eigenvalue of a matrix or an       *
%* interval matrix.                                                       *
%* The bound is computed with a formula that comes from the               *
%* theorem of Gerschgorin.                                                *
%*                                                                        *
%**************************************************************************
%*                                                                        *
%*  This program is free software: you can redistribute it and/or modify  *
%*  it under the terms of the GNU General Public License as published by  *
%*  the Free Software Foundation, either version 3 of the License, or     *
%*  (at your option) any later version.                                   *
%*                                                                        *
%*  This program is distributed in the hope that it will be useful,       *
%*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
%*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
%*  GNU General Public License for more details.                          *
%*                                                                        *
%*  You should have received a copy of the GNU General Public License     *
%*  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
%*                                                                        *
%**************************************************************************
%*                                                                        *
%* P.Steuermann - IOR/Karlsruhe Institute of Technology                   *
%* vers.: 0.0.1-0001 - 13/06/2010                                         *
%*                                                                        *
%**************************************************************************

if isa(M,'double')
    val = min(diag(M)-sum(abs(M-diag(diag(M)))')');
else
    n=size(M);
    D = zeros(n,1);
    for i=1:n(1)
        D(i)   = inf(M(i,i));
        M(i,i) = infsup(0,0);
    end
    M = sup(abs(M));
    val = min(D-sum(M')');
end