function [val,dval] = f_alpha(x,fname,alpha_relax,lb,ub)

%**************************************************************************
%* F_ALPHA is the convex relaxation of the function fname on a box        *
%* [lb,ub] that is used in the alpha B&B method.                          *
%* It computes the value and the first derivative of the convex           *
%* relaxation.                                                            *
%*                                                                        *
%* For more information see:                                              *
%*                                                                        *
%* C.S.Adjiman, C.A.Androulakis, C.A.Floudas                              *
%* A Global Optimization Method, αBB, for general twice-differentiable    *
%* constrained NLPs - I: Theoretical advances                             *
%* Computers and Chemical Engineering, 22 (1998), pp. 1137-1158           *
%*                                                                        *
%* C.S.Adjiman, C.A.Androulakis, C.A.Floudas                              *
%* A Global Optimization Method, αBB, for general twice-differentiable    *
%* constrained NLPs - II: Implementation and computational results        *
%* Computers and Chemical Engineering, 22 (1998), pp. 1159-1179           *
%*                                                                        *
%**************************************************************************
%*                                                                        *
%*  This program is free software: you can redistribute it and/or modify  *
%*  it under the terms of the GNU General Public License as published by  *
%*  the Free Software Foundation, either version 3 of the License, or     *
%*  (at your option) any later version.                                   *
%*                                                                        *
%*  This program is distributed in the hope that it will be useful,       *
%*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
%*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
%*  GNU General Public License for more details.                          *
%*                                                                        *
%*  You should have received a copy of the GNU General Public License     *
%*  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
%*                                                                        *
%**************************************************************************
%*                                                                        *
%* P.Steuermann - IOR/Karlsruhe Institute of Technology                   *
%* vers.: 0.0.1-0001 - 13/06/2010                                         *
%*                                                                        *
%**************************************************************************

if nargout<2
    val = fname(x) - 0.5*alpha_relax*(lb-x)'*(ub-x);
end

if nargout>1
    [F,DF] = fname(x);
    val    = F - 0.5*alpha_relax*(lb-x)'*(ub-x);
    dval   = DF+0.5*alpha_relax*(2*x-ub-lb);
end