function test

%--------------------------------------------------------------------------
% Testfunction for gosolver
% _________________________
%
% For more information on gosolver see README or type 
% help gosolver. 
%
% first example  : Rosenbrock function with box constraints.
% second example : Rosenbrock function with box constraints and 
%                  the linear constraint -x_1-x_2+1<=0.
% third example  : Rosenbrock function with box constraints and
%                  the nonlinear constraints -x_1^2-x_2^2+1<=0,
%                  x_1^2+x_2^2-1<=0.
% fourth example : Rosenbrock function with box constraints 
%                  (not the default options!)
% 
%--------------------------------------------------------------------------
% KIT/IOR - 04/02/2012
%--------------------------------------------------------------------------

%-----------------------------------
% box constraints 
%-----------------------------------
lb = [-2;-2];
ub = [2;2];

%-----------------------------------
% options for the algorithm
% (un-)comment options you wish
%-----------------------------------
options.Algori = 'ufBB';
%options.Algori = 'hybBB';

options.Point  = 'min';

options.Split  = 'gradmax';
%options.Split = 'gradmid';
%options.Split = 'ratz';
%options.Split = 'relmax';

%options.debug = [];

%-----------------------------------
% first example
%-----------------------------------
disp('First example: Compute the minimum of the Rosenbrock function on [-2,2]^2')
disp('Press any key to continue')
pause

[x,fval_low,fval_up,exitflag,output] = gosolver(@rosenbrock,lb,ub);

fprintf('\nAlgorithm %s stopped with exitflag %u\nafter %u iterations.\n',output.Algori,exitflag,output.iter);
fprintf('The exit message is: %s\n',output.Term);
fprintf('A lower bound for the optimal value is: %f\n',fval_low);
fprintf('An upper bound for the optimal value is: %f\n\n',fval_up);

disp('Press any key to continue with the second example or crtl+c to abort')
pause
disp(' ')

%-----------------------------------
% second example
%-----------------------------------
disp('Second example: Compute the minimum of the Rosenbrock function on [-2,2]^2 with the additional constraint -x_1-x_2+1<=0')
disp('Press any key to continue')
pause

[x,fval_low,fval_up,exitflag,output] = gosolver(@rosenbrock,lb,ub,@simp);

fprintf('\nAlgorithm %s stopped with exitflag %u\nafter %u iterations.\n',output.Algori,exitflag,output.iter);
fprintf('The exit message is: %s\n',output.Term);
fprintf('A lower bound for the optimal value is: %f\n',fval_low);
fprintf('An upper bound for the optimal value is: %f\n\n',fval_up);

disp('Press any key to continue with the third example or crtl+c to abort')
pause
disp(' ')

%-----------------------------------
% third example
%-----------------------------------
disp('Third example: Compute the minimum of the Rosenbrock function on [-2,2]^2 with the additional constraint -x_1^2-x_2^2+1<=0')
disp('Press any key to continue')
pause

[x,fval_low,fval_up,exitflag,output] = gosolver(@rosenbrock,lb,ub,@circ,options);

fprintf('\nAlgorithm %s stopped with exitflag %u\nafter %u iterations.\n',output.Algori,exitflag,output.iter);
fprintf('The exit message is: %s\n',output.Term);
fprintf('A lower bound for the optimal value is: %f\n',fval_low);
fprintf('An upper bound for the optimal value is: %f\n\n',fval_up);

%-----------------------------------
% fourth example
%-----------------------------------
disp('Fourth example: Compute the minimum of the Rosenbrock function on [-2,2]^2')
disp('Press any key to continue')
pause

[x,fval_low,fval_up,exitflag,output] = gosolver(@rosenbrock,lb,ub,[],options);

fprintf('\nAlgorithm %s stopped with exitflag %u\nafter %u iterations.\n',output.Algori,exitflag,output.iter);
fprintf('The exit message is: %s\n',output.Term);
fprintf('A lower bound for the optimal value is: %f\n',fval_low);
fprintf('An upper bound for the optimal value is: %f\n\n',fval_up);
